use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Annotations
App
CLI
Document
ExportInspector
Include
Ishigaki
Kenichi
Logger
Mendoza
Nicolas
Olaf
PPI
Role
Sandbox
dump
ishigaki
lib
mendoza
olaf
perlimports
sandboxed
script
